@@ -226,7 +226,7 @@ use Glib::Object::Subclass Gscan2pdf::Dialog::, signals => {
     ),
   ];
 
-our $VERSION = '1.3.9';
+our $VERSION = '1.4.0';
 
 my ( $d, $d_sane, $logger, $tooltips );
 my $tolerance = 1;
@@ -341,8 +341,9 @@ sub INIT_INSTANCE {
     }
 
     # Toggle to switch between basic and extended modes
-    my $checkx = Gtk2::CheckButton->new( $d->get('Extended page numbering') );
-    $vbox1->pack_start( $checkx, FALSE, FALSE, 0 );
+    $self->{checkx} =
+      Gtk2::CheckButton->new( $d->get('Extended page numbering') );
+    $vbox1->pack_start( $self->{checkx}, FALSE, FALSE, 0 );
 
     # Frame for extended mode
     $self->{framex} = Gtk2::Frame->new( $d->get('Page number') );
@@ -475,8 +476,9 @@ sub INIT_INSTANCE {
         }
     );
 
-# Have to put the extended pagenumber checkbox here to reference simple controls
-    $checkx->signal_connect(
+    # Have to put the extended pagenumber checkbox here
+    # to reference simple controls
+    $self->{checkx}->signal_connect(
         toggled => \&_extended_pagenumber_checkbox_callback,
         [ $self, $frames, $spin_buttoni ]
     );
@@ -961,7 +963,9 @@ sub set_paper_formats {
         }
 
         # Set the combobox back from Edit to the previous value
-        set_combobox_by_text( $combobp, $self->get('paper') );
+        my $paper = $self->get('paper');
+        if ( not defined $paper ) { $paper = $d->get('Manual') }
+        set_combobox_by_text( $combobp, $paper );
     }
     return;
 }
@@ -1205,6 +1209,8 @@ sub set_profile {
                 # set property before emitting signal to ensure callbacks
                 # receive correct value
                 $self->{profile} = $name;
+                my $paper = $self->get_paper_by_geometry;
+                if ( defined $paper ) { $self->set( 'paper', $paper ) }
                 $self->signal_emit( 'changed-profile', $name );
             }
         );
@@ -1318,15 +1324,15 @@ sub _extended_pagenumber_checkbox_callback {
     }
     else {
         if ( $spin_buttoni->get_value == 1 ) {
-            $widget->{buttons}->set_active(TRUE);
+            $dialog->{buttons}->set_active(TRUE);
         }
         elsif ( $spin_buttoni->get_value > 0 ) {
-            $widget->{buttond}->set_active(TRUE);
-            $widget->{combobs}->set_active(0);
+            $dialog->{buttond}->set_active(TRUE);
+            $dialog->{combobs}->set_active(FALSE);
         }
         else {
-            $widget->{buttond}->set_active(TRUE);
-            $widget->{combobs}->set_active(1);
+            $dialog->{buttond}->set_active(TRUE);
+            $dialog->{combobs}->set_active(TRUE);
         }
         $frames->show_all;
         $dialog->{framex}->hide_all;
