@@ -77,7 +77,7 @@ use Glib::Object::Subclass Gscan2pdf::Dialog::Scan::, signals => {
     ),
   ];
 
-our $VERSION = '1.3.9';
+our $VERSION = '1.4.0';
 
 my $SANE_NAME_PAGE_HEIGHT = SANE_NAME_PAGE_HEIGHT;
 my $SANE_NAME_PAGE_WIDTH  = SANE_NAME_PAGE_WIDTH;
@@ -239,6 +239,7 @@ sub scan_options {
             # This fires the reloaded-scan-options signal,
             # so don't set this until we have finished
             $self->set( 'available-scan-options', $options );
+            $self->set_paper_formats( $self->{paper_formats} );
             return;
         }
     }
@@ -303,6 +304,7 @@ sub scan_options {
             # This fires the reloaded-scan-options signal,
             # so don't set this until we have finished
             $self->set( 'available-scan-options', $options );
+            $self->set_paper_formats( $self->{paper_formats} );
         },
         error_callback => sub {
             my ($message) = @_;
@@ -323,9 +325,8 @@ sub _initialise_options {    ## no critic (ProhibitExcessComplexity)
 
     # We have hereby removed the active profile and paper,
     # so update the properties without triggering the signals
-    $self->{profile}       = undef;
-    $self->{paper_formats} = undef;
-    $self->{paper}         = undef;
+    $self->{profile} = undef;
+    $self->{paper}   = undef;
 
     # Default tab
     my $vbox = Gtk2::VBox->new;
@@ -470,9 +471,6 @@ sub _initialise_options {    ## no critic (ProhibitExcessComplexity)
         $self->pack_widget( $widget, [ $options, $opt, $hbox ] );
     }
 
-    # Set defaults
-    my $sane_device = Gscan2pdf::Frontend::CLI->device;
-
     # Callback for option visibility
     $self->signal_connect(
         'changed-option-visibility' => sub {
@@ -545,10 +543,6 @@ sub _update_option_visibility {
         }
     }
 
-    # In case the geometry values have changed,
-    # update the available paper formats
-    $self->set_paper_formats( $self->{paper_formats} );
-
     if ( defined $visible_options->{'Paper size'} ) {
         $self->{hboxp}->show_all;
     }
@@ -744,6 +738,28 @@ sub hide_geometry {
     return;
 }
 
+sub get_paper_by_geometry {
+    my ($self) = @_;
+    my $formats = $self->get('paper-formats');
+    if ( not defined $formats ) { return }
+    my $options = $self->get('available-scan-options');
+    my %current;
+    for (qw(l t x y)) {
+        $current{$_} = $options->by_name($_)->{val};
+    }
+    for my $paper ( keys %{$formats} ) {
+        my $match = TRUE;
+        for (qw(l t x y)) {
+            if ( $formats->{$paper}{$_} != $current{$_} ) {
+                $match = FALSE;
+                last;
+            }
+        }
+        if ($match) { return $paper }
+    }
+    return;
+}
+
 # Update the sane option in the thread
 # If necessary, reload the options,
 # and walking the options tree, update the widgets
