@@ -24,7 +24,7 @@ use Glib::Object::Subclass Gscan2pdf::Dialog::Scan::, properties => [
     ),
 ];
 
-our $VERSION = '1.3.9';
+our $VERSION = '1.4.0';
 
 my $SANE_NAME_SCAN_TL_X   = SANE_NAME_SCAN_TL_X;
 my $SANE_NAME_SCAN_TL_Y   = SANE_NAME_SCAN_TL_Y;
@@ -148,6 +148,7 @@ sub scan_options {
                     # This fires the reloaded-scan-options signal,
                     # so don't set this until we have finished
                     $self->set( 'available-scan-options', $options );
+                    $self->set_paper_formats( $self->{paper_formats} );
                 },
                 sub {    # error callback
                     my ($message) = @_;
@@ -180,9 +181,8 @@ sub _initialise_options {    ## no critic (ProhibitExcessComplexity)
 
     # We have hereby removed the active profile and paper,
     # so update the properties without triggering the signals
-    $self->{profile}       = undef;
-    $self->{paper_formats} = undef;
-    $self->{paper}         = undef;
+    $self->{profile} = undef;
+    $self->{paper}   = undef;
 
     delete $self->{combobp}; # So we don't carry over from one device to another
     for ( 1 .. $num_dev_options - 1 ) {
@@ -325,9 +325,6 @@ sub _initialise_options {    ## no critic (ProhibitExcessComplexity)
         $self->pack_widget( $widget, [ $options, $opt, $hbox, $hboxp ] );
     }
 
-    # Set defaults
-    my $sane_device = Gscan2pdf::Frontend::Sane->device();
-
     # Show new pages
     for ( 1 .. $self->{notebook}->get_n_pages - 1 ) {
         $self->{notebook}->get_nth_page($_)->show_all;
@@ -525,6 +522,30 @@ sub hide_geometry {
     return;
 }
 
+sub get_paper_by_geometry {
+    my ($self) = @_;
+    my $formats = $self->get('paper-formats');
+    if ( not defined $formats ) { return }
+    my $options = $self->get('available-scan-options');
+    my %current = (
+        l => $options->by_name(SANE_NAME_SCAN_TL_X)->{val},
+        t => $options->by_name(SANE_NAME_SCAN_TL_Y)->{val},
+    );
+    $current{x} = $current{l} + $options->by_name(SANE_NAME_SCAN_BR_X)->{val};
+    $current{y} = $current{t} + $options->by_name(SANE_NAME_SCAN_BR_Y)->{val};
+    for my $paper ( keys %{$formats} ) {
+        my $match = TRUE;
+        for (qw(l t x y)) {
+            if ( $formats->{$paper}{$_} != $current{$_} ) {
+                $match = FALSE;
+                last;
+            }
+        }
+        if ($match) { return $paper }
+    }
+    return;
+}
+
 # Update the sane option in the thread
 # If necessary, reload the options,
 # and walking the options tree, update the widgets
