@@ -24,7 +24,7 @@ Readonly my $_SANE_STATUS_EOF             => 5;      # or we could use Sane
 Readonly my $_1KB                         => 1024;
 Readonly my $ALL_PENDING_ZOMBIE_PROCESSES => -1;
 
-our $VERSION = '1.3.9';
+our $VERSION = '1.4.0';
 
 my $EMPTY = q{};
 my $COMMA = q{,};
@@ -66,7 +66,8 @@ sub parse_device_list {
 
     my (@device_list);
 
-    if ( defined $output ) { $logger->info($output) }
+    if ( not defined $output ) { return [] }
+    $logger->info($output);
 
     # parse out the device and model names
     my @words =
@@ -97,7 +98,6 @@ sub find_scan_options {
     }
 
     # Get output from scanimage or scanadf.
-    # Inverted commas needed for strange characters in device name
     my $cmd = _create_scanimage_cmd( \%options );
 
     _watch_cmd(
